@@ -11,9 +11,11 @@ test_that("Checking a data set works",{
 test_that("Showing data errors works",{
    edt <- editmatrix(editrules = "2*x==y\n5*x==y")
    dat <- data.frame(x=c(2,1), y=c(4,5))
-   errors <- errorMatrix(edt, dat)
+   errors <- violatedEdits(edt, dat)
    
    # rule names equal?
+   print(dat)
+   print(errors)
    expect_equal(colnames(errors), rownames(edt))
    
    dimnames(errors) <- NULL
@@ -31,7 +33,7 @@ test_that("Showing data errors works",{
 test_that("Error lists works",{
    edt <- editmatrix(editrules = "2*x==y\n5*x==y")
    dat <- data.frame(x=c(2,1), y=c(4,5))
-   errors <- listErrors(edt, dat)
+   errors <- listViolatedEdits(edt, dat)
    #expect_equal(errors, list("1"=c(2), "2"=c(1)))
    #print(str(errors))
    #print(showErrors(dat, edt)) 
